@@ -29,7 +29,7 @@ try:
 except ImportError:
     pass
 
-__version__ = "1.16.4"
+__version__ = "1.17.0"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_ImageLoad.git"
 
 
@@ -80,4 +80,8 @@ def load(
             from . import gif
 
             return gif.load(file, bitmap=bitmap, palette=palette)
+        if header.startswith(b"\x89PN"):
+            from . import png
+
+            return png.load(file, bitmap=bitmap, palette=palette)
         raise RuntimeError("Unsupported image format")
